import { world, system } from "@minecraft/server";
import { ActionFormData, ModalFormData } from "@minecraft/server-ui";
function menu(p) {
    const score = world.scoreboard.getObjective('afkScore');
    let config = new ModalFormData();
    config.slider('AFK DELAY(seconds) | 0 = disabled\n', 0, 100, 1, score.getScore('tickAfkDelay'));
    config.show(p).then(r => {
        if (r.canceled) return;
        score.setScore('tickAfkDelay', r.formValues[0])
    })
};
world.afterEvents.itemUse.subscribe(ev => {
    if (ev.itemStack.typeId !== 'minecraft:slime_ball' || !ev.source.hasTag('admin')) return;
    menu(ev.source)
});
world.afterEvents.worldInitialize.subscribe(() => {
    if (!world.scoreboard.getObjective('afkScore')) {
        world.scoreboard.addObjective('afkScore', 'afkScore');
        const score = world.scoreboard.getObjective('afkScore');
        score.setScore('tickAfkDelay', 10);

    }
});
function getScore(jugador, objetivo) {
    try {
        const score = world.scoreboard.getObjective(objetivo)
        if (score.hasParticipant(jugador)) {
            const puntuacion = score.getScore(jugador);
            return puntuacion
        } else {
            return 0;
        }
    } catch (error) {
        return 0;
    }
};
const coordenadasJugadores = {};
const tiempoInactivoRequerido = 20;
system.runInterval(() => {
    for (const p of world.getPlayers()) {
        const jugador = p.name;
        const coordenadasActuales = {
            x: p.location.x,
            y: p.location.y,
            z: p.location.z,
            hx: p.getRotation().x,
            hy: p.getRotation().y
        };
        if (coordenadasJugadores[jugador]) {
            if (
                coordenadasActuales.x !== coordenadasJugadores[jugador].x ||
                coordenadasActuales.y !== coordenadasJugadores[jugador].y ||
                coordenadasActuales.z !== coordenadasJugadores[jugador].z ||
                coordenadasActuales.hx !== coordenadasJugadores[jugador].hx ||
                coordenadasActuales.hy !== coordenadasJugadores[jugador].hy &&
                p.hasTag('isAfk')
            ) {
                p.camera.clear();
                coordenadasJugadores[jugador].tiempoInactivo = 0;
                p.removeTag('isAfk');
            }
            else {
                coordenadasJugadores[jugador].tiempoInactivo++;
                if (coordenadasJugadores[jugador].tiempoInactivo >= tiempoInactivoRequerido * getScore('tickAfkDelay', 'afkScore')) {
                    p.addTag('isAfk');
                }
            }
        } else {
            coordenadasJugadores[jugador] = {
                tiempoInactivo: 0
            };
        }
        coordenadasJugadores[jugador] = {
            ...coordenadasActuales,
            tiempoInactivo: coordenadasJugadores[jugador].tiempoInactivo
        };
    }
});
system.runInterval(() => {
    for (const p of world.getPlayers().filter(p => p.hasTag('isAfk'))) {
        if (world.scoreboard.getObjective('afkScore').getScore('tickAfkDelay') === 0) return;
        const xAleatorio = p.location.x + Math.floor(Math.random() * (2 * 2 + 1)) - 2;
        const zAleatorio = p.location.z + Math.floor(Math.random() * (2 * 2 + 1)) - 2;
        const yAleatorio = p.getHeadLocation().y + 1 + Math.floor(Math.random() * (2 * 1 + 1)) - 2;
        const cameraLocation = {
            x: xAleatorio,
            y: yAleatorio,
            z: zAleatorio
        };
        const facingLoc = {
            x: p.location.x,
            y: p.getHeadLocation().y,
            z: p.location.z
        };
        const random = Math.random();
        if (random > 0.7) {
            p.camera.fade({ fadeTime: { fadeInTime: random, holdTime: 0.5, fadeOutTime: random } });
        }
        p.camera.setCamera('minecraft:free', { location: cameraLocation, facingLocation: facingLoc, easeOptions: { easeTime: 2.5 } });
    }
}, 50);
world.afterEvents.playerLeave.subscribe(ev => {
    for (const jugador in coordenadasJugadores) {
        if (world.getPlayers().filter(p => p.name === jugador).length < 1) {
            delete coordenadasJugadores[jugador];
        }
    }
});